# qe-tools
This repository contains a set of useful tools for Quantum ESPRESSO, in particular

 * a parser for pw.x input files
 * a parser for cp.x input files

The code is developed and maintained by the AiiDA Team and is licensed under the MIT license (see LICENSE file).


